/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: pgxexplorer.h */
#define STDSTRING 1024
#define MAXPATH 2048
#define TEMPLATE "template1"
PGconn* connection;	/* variables here */
char* currentbase;
char tmpstr[STDSTRING];
GtkWidget* main_wnd;
GtkWidget* query_exec;
int connected=0;
int timeout=10;
